price_weather_option: Price HDD and CDD Weather Derivatives

View source: R/04_option_pricing.R

price_weather_optionR Documentation

Price HDD and CDD Weather Derivatives

Description

Evaluates fair values and Monte Carlo standard errors for HDD and CDD Call Options.

Usage

price_weather_option(
  temp_paths,
  strike,
  type = c("HDD", "CDD"),
  r = 0.04,
  base_temp = 18
)

Arguments

temp_paths

Matrix of simulated temperature paths from simulate_weather_paths.

strike

Strike index level K.

type

Option contract type: "HDD" or "CDD".

r

Risk-free discount rate (default 0.04).

base_temp

Threshold index baseline (default 18.0 deg C).

Value

A list containing estimated price, standard error, and index distribution metrics.

Examples

paths <- simulate_weather_paths(n_paths = 100, days = 90)
hdd_opt <- price_weather_option(paths, strike = 500, type = "HDD")
print(hdd_opt$price)

weatherMRJD documentation built on Aug. 20, 2026, 5:10 p.m.